import React, { useState, useEffect } from 'react';
import { onDpDataChange, offDpDataChange } from '@ray-js/api';
import { useAtomValue, useSetAtom } from 'jotai';
import { DpState, dpStateAtom, selectDpStateAtom } from '@/atoms';
import { getDpStateMapByDevInfo, mapDpsMapToDpStateMap, getDpCodeMapByDevInfo } from '@/utils';
import { ScrollView, View, Text, Image } from '@ray-js/components';
import HubCircle from '@/components/hubCircle';
import HubColorCircle from '@/components/hubColorCircle';
import { hooks, kit } from '@ray-js/panel-sdk';
import styles from './index.module.less';
import imgs from '../../res';

const { useDevInfo, useDpState, usePanelConfig } = hooks;
const { getDevInfo, initDevInfo } = kit;

export function Home() {
  const devInfo = useDevInfo();
  const panelConfig = usePanelConfig();

  const [dpState, setDpState] = useDpState();
  const dpStateInUseDpState = dpState as unknown as DpState;

  const setDpStateAtom = useSetAtom(dpStateAtom);
  const dpStateInAtom = useAtomValue(selectDpStateAtom);

  const handleDpDataChange: DpDataChangeHandler = data => {
    const initalDevInfo = getDevInfo();
    // 转化为 dpState 格式
    const newDpState = mapDpsMapToDpStateMap(data.dps, initalDevInfo) as DpState;
    console.log(newDpState, '123', dpState);
    //  {switch: true} 输出更改的值
    setDpStateAtom(newDpState);
  };

  useEffect(() => {
    // 绑定设备
    initDevInfo().then(initalDevInfo => {
      // 转化为 dpState 格式
      const initialDpState = getDpStateMapByDevInfo(initalDevInfo) as DpState;
      //   初始化原子
      setDpStateAtom(initialDpState);
      //   监听设备状态变更
      onDpDataChange(handleDpDataChange);
    });
    return () => {
      // 取消监听
      offDpDataChange(handleDpDataChange);
    };
  }, []);

  useEffect(() => {
    console.log(panelConfig);
  }, [panelConfig.initialized]);

  const DpStateData = dpStateInUseDpState || (getDpStateMapByDevInfo(devInfo) as DpState);

  const DpCodesMap = getDpCodeMapByDevInfo(devInfo);

  const handleSetPdState = (dpCode: string, dpValue: any) => {
    setDpState({
      [dpCode]: dpValue,
    });
  };

  const handleSwitch = (e: any) => {
    e.origin.stopPropagation();
    handleSetPdState('switch_led', !DpStateData.switch_led);
  };

  return (
    <ScrollView>
      <View className={styles.home}>
        <View className={styles.content}>
          <View className={styles.tabCards}>
            <View
              className={DpStateData.work_mode === 'white' ? styles.tabItemActive : styles.tabItem}
              onClick={() => {
                handleSetPdState('work_mode', 'white');
              }}
            >
              White
            </View>
            <View
              className={DpStateData.work_mode === 'colour' ? styles.tabItemActive : styles.tabItem}
              onClick={() => {
                handleSetPdState('work_mode', 'colour');
              }}
            >
              Color
            </View>
          </View>
          {DpStateData.switch_led && (
            <View className={styles.tabContent}>
              {DpStateData.work_mode === 'white' ? (
                <HubCircle
                  DpStateData={DpStateData}
                  DpCodesMap={DpCodesMap}
                  onSetDpState={handleSetPdState}
                />
              ) : (
                <HubColorCircle
                  DpStateData={DpStateData}
                  DpCodesMap={DpCodesMap}
                  onSetDpState={handleSetPdState}
                />
              )}
            </View>
          )}
        </View>
        <View className={styles.subtract}>
          <View
            onClick={handleSwitch}
            className={`${styles.switch} ${!DpStateData.switch_led ? styles.switchActive : ''}`}
          >
            <Image
              src={imgs.CombinedShapeWhite}
              style={{ display: DpStateData.switch_led ? 'inline-block' : 'none' }}
              className={styles.CombinedShape}
            />
            <Image
              src={imgs.CombinedShape}
              style={{ display: DpStateData.switch_led ? 'none' : 'inline-block' }}
              className={styles.CombinedShape}
            />
          </View>
        </View>
      </View>
    </ScrollView>
  );
}

export default Home;
